summaryrefslogtreecommitdiff
path: root/qa
diff options
context:
space:
mode:
authorGitLab Bot <gitlab-bot@gitlab.com>2022-03-02 03:13:05 +0000
committerGitLab Bot <gitlab-bot@gitlab.com>2022-03-02 03:13:05 +0000
commit1a54a22498c83026e61d30d36c9c599938664454 (patch)
tree00774b3d97d24f001390341b1e9c88f2c45669a8 /qa
parent90c386a7b0f2701abeb1e86517fc1d5dea231c09 (diff)
downloadgitlab-ce-1a54a22498c83026e61d30d36c9c599938664454.tar.gz
Add latest changes from gitlab-org/gitlab@master
Diffstat (limited to 'qa')
-rw-r--r--qa/qa/page/project/web_ide/edit.rb2
-rw-r--r--qa/qa/tools/delete_test_users.rb10
2 files changed, 6 insertions, 6 deletions
diff --git a/qa/qa/page/project/web_ide/edit.rb b/qa/qa/page/project/web_ide/edit.rb
index 403c919c6e5..435cc4a717e 100644
--- a/qa/qa/page/project/web_ide/edit.rb
+++ b/qa/qa/page/project/web_ide/edit.rb
@@ -32,7 +32,7 @@ module QA
element :file_template_dropdown
end
- view 'app/assets/javascripts/ide/components/file_templates/dropdown.vue' do
+ view 'app/assets/javascripts/ide/components/file_templates/bar.vue' do
element :dropdown_filter_input
end
diff --git a/qa/qa/tools/delete_test_users.rb b/qa/qa/tools/delete_test_users.rb
index 1f69f1bc548..c60e6a6af44 100644
--- a/qa/qa/tools/delete_test_users.rb
+++ b/qa/qa/tools/delete_test_users.rb
@@ -5,8 +5,8 @@
# - If `dry_run` is true the script will list the users to be deleted by username, but it won't delete them
# - Specify `exclude_users` as a comma-separated list of usernames to not delete.
#
# Required environment variables: GITLAB_QA_ACCESS_TOKEN and GITLAB_ADDRESS
# - GITLAB_QA_ACCESS_TOKEN must have admin API access
module QA
module Tools
@@ -19,9 +19,9 @@ module QA
def initialize(delete_before: (Date.today - 1).to_s, dry_run: 'false', exclude_users: nil)
raise ArgumentError, "Please provide GITLAB_ADDRESS" unless ENV['GITLAB_ADDRESS']
- raise ArgumentError, "Please provide GITLAB_QA_ACCESS_TOKEN" unless ENV['GITLAB_QA_ACCESS_TOKEN']
+ raise ArgumentError, "Please provide GITLAB_QA_ADMIN_ACCESS_TOKEN" unless ENV['GITLAB_QA_ADMIN_ACCESS_TOKEN']
- @api_client = Runtime::API::Client.new(ENV['GITLAB_ADDRESS'], personal_access_token: ENV['GITLAB_QA_ACCESS_TOKEN'])
+ @api_client = Runtime::API::Client.new(ENV['GITLAB_ADDRESS'], personal_access_token: ENV['GITLAB_QA_ADMIN_ACCESS_TOKEN'])
@dry_run = !FALSY_VALUES.include?(dry_run.to_s.downcase)
@delete_before = Date.parse(delete_before)
@page_no = '1'
@@ -29,7 +29,7 @@ module QA
end
def run
- puts "Deleting users with a username starting with 'qa-user-' created before #{@delete_before}..."
+ puts "Deleting users with a username starting with 'qa-user-' or 'test-user-' created before #{@delete_before}..."
while page_no.present?
users = fetch_test_users
@@ -5,8 +5,8 @@
# - Specify `exclude_users` as a comma-separated list of usernames to not delete.
#
-# Required environment variables: GITLAB_QA_ACCESS_TOKEN and GITLAB_ADDRESS
-# - GITLAB_QA_ACCESS_TOKEN must have admin API access
+# Required environment variables: GITLAB_QA_ADMIN_ACCESS_TOKEN and GITLAB_ADDRESS
+# - GITLAB_QA_ADMIN_ACCESS_TOKEN must have admin API access
module QA
module Tools